@@ -3,14 +3,11 @@
 #' @param df1 A data frame
 #' @param df2 An optional second data frame for comparing categorical levels.  
 #' Defaults to \code{NULL}.
-#' @param show_plot Logical determining whether to show a plot in addition 
-#' to tibble output.  Default is \code{FALSE}.
 #' @param breaks Optional argument determining how breaks are constructed for 
 #' histograms when comparing numeric data frame features.  This is passed to 
+#' @param show_plot (Deprecated) Logical flag indicating whether a plot should be shown.  
+#' Superseded by the function \code{show_plot()} and will be dropped in a future version.
 #' \code{hist(..., breaks)}.  See \code{?hist} for more details. 
-#' @param plot_layout Vector specifying the number of rows and columns 
-#' in the plotting grid.  For example, 3 rows and 2 columns would be specified as 
-#' \code{plot_layout = c(3, 2)}.
 #' @param breakseq For internal use only.  Argument that accepts a pre-specified set of 
 #' break points, default is \code{NULL}.
 #' @return A \code{tibble} containing statistical summaries of the numeric 
@@ -34,13 +31,11 @@
 #'   \item \code{hist_1}, \code{hist_2} list column for histograms of each of \code{df1} and \code{df2}.
 #'   Where a column appears in both dataframe, the bins used for \code{df1} are reused to 
 #'   calculate histograms for \code{df2}.
-#'   \item{psi} numeric column containing the 
-#'   \href{https://www.quora.com/What-is-population-stability-index}{population stability index}.  
-#'   This measures the change in distribution of two numeric features.  Conventionally, values
-#'   exceeding 0.25 indicate strong evidence of a change, with values below 0.25 and 0.1 
-#'   representing moderate and low evidence of a change.
+#'   \item{jsd} numeric column containing the Jensen-Shannon divergence.  This measures the 
+#'   difference in distribution of a pair of binned numeric features.  Values near to 0 indicate
+#'   agreement of the distributions, while 1 indicates disagreement.
 #'   \item{fisher_p} p-value corresponding to Fisher's exact test.  A small p indicates 
-#'   evidence that the the two histograms are actually different.
+#'   evidence that the two histograms are actually different.
 #' }
 #' @export
 #' @examples
@@ -50,7 +45,7 @@
 #' # with a visualisation too - try to limit number of bins
 #' inspect_num(starwars, breaks = 10)
 #' # compare two data frames
-#' inspect_num(starwars, starwars[-c(1:10), ], breaks = 10, show_plot = TRUE)
+#' inspect_num(starwars, starwars[-c(1:10), ], breaks = 10)
 #' @importFrom dplyr arrange
 #' @importFrom dplyr contains
 #' @importFrom dplyr desc
@@ -63,15 +58,6 @@
 #' @importFrom dplyr select
 #' @importFrom dplyr slice
 #' @importFrom dplyr ungroup
-#' @importFrom ggplot2 aes
-#' @importFrom ggplot2 facet_grid
-#' @importFrom ggplot2 facet_wrap
-#' @importFrom ggplot2 geom_col
-#' @importFrom ggplot2 geom_tile
-#' @importFrom ggplot2 ggplot
-#' @importFrom ggplot2 labs
-#' @importFrom ggplot2 scale_fill_gradient
-#' @importFrom ggplot2 theme
 #' @importFrom magrittr %>%
 #' @importFrom graphics hist
 #' @importFrom stats median
@@ -81,8 +67,8 @@
 #' @importFrom tidyr gather
 #' @importFrom utils tail
 
-inspect_num <- function(df1, df2 = NULL, show_plot = F, 
-                       breaks = 20, plot_layout = NULL, breakseq = NULL){
+inspect_num <- function(df1, df2 = NULL,
+                       breaks = 20, breakseq = NULL, show_plot = FALSE){
 
   # perform basic column check on dataframe input
   check_df_cols(df1)
@@ -91,8 +77,10 @@ inspect_num <- function(df1, df2 = NULL, show_plot = F,
   if(is.null(df2)){
     # pick out numeric features
     df_num <- df1 %>% select_if(is.numeric)
+    n_cols <- ncol(df_num)
     # calculate summary statistics for each
-    if(ncol(df_num) > 0){
+    if(n_cols > 0){
+      names_vec <- colnames(df1)
       # use the summary function to sweep out statistics
       df_num_sum <- df_num %>% gather(key = "col_name", value = "value") %>%
         group_by(col_name) %>% 
@@ -111,64 +99,61 @@ inspect_num <- function(df1, df2 = NULL, show_plot = F,
       if(!is.null(breakseq)){
         breaks_tbl <- left_join(breaks_tbl, breakseq, by = "col_name")
       } else {
-        breaks_tbl$breaks <- as.list(rep(NA, nrow(breaks_tbl)))
+        # if not supplied, create placeholder list of NULLs
+        breaks_tbl$breaks <- lapply(as.list(1:nrow(breaks_tbl)), function(xc) NULL)
       }
-      breaks_tbl$hist <- vector("list", length = ncol(df_num))
-      # loop over the breaks_tbl and generate histograms, suppress plotting
+      pb <- start_progress(prefix = " Column", total = n_cols)
+      breaks_tbl$hist <- vector("list", length = nrow(breaks_tbl))
+      # loop over the breaks_tbl and generate histograms, suppressing plotting
+      # if breaks already exist, then use them, otherwise create new breaks
       for(i in 1:nrow(breaks_tbl)){
-        brks_na <- anyNA(breaks_tbl$breaks[[i]])
-        breaks_tbl$hist[[i]] <- hist(unlist(df_num[breaks_tbl$col_name[i]]), plot = F, 
-                                     breaks = if(brks_na) breaks else {breaks_tbl$breaks[[i]]}, 
-                                     right = FALSE)
+        update_progress(bar = pb, iter = i, total = nrow(breaks_tbl), what = names_vec[i])
+        # substract out mean to avoid numerical issues
+        brks_null <- is.null(breaks_tbl$breaks[[i]])
+        hist_i    <- suppressWarnings(hist(df_num[[breaks_tbl$col_name[i]]], 
+                                           plot = FALSE, 
+                                           breaks = if(brks_null) breaks else {breaks_tbl$breaks[[i]]}, 
+                                           right = FALSE))
+        # extract basic info for constructing hist
+        breaks_tbl$hist[[i]] <- prop_value(hist_i)
       }
-      # extract basic info for constructing hist
-      breaks_tbl$hist <- lapply(breaks_tbl$hist, prop_value)
       # ensure the histogram has a min and max breaks & join back to df_num_sum
       out <- left_join(df_num_sum, breaks_tbl, by = "col_name") %>% 
         select(-breaks)
       # add feature names to the list
       names(out$hist) <-  as.character(out$col_name)
-      # if plot is requested
-      if(show_plot){
-        plot_num_1(out, 
-                   df_names = df_names, 
-                   plot_layout = plot_layout)
-      }
-      # return df
-      return(out)
+      # attach attributes required for plotting
+      attr(out, "type") <- list("num", 1)
+      attr(out, "df_names") <- df_names
     } else {
-      return(tibble(col_name = character(), min = numeric(), 
+      out <- tibble(col_name = character(), min = numeric(), 
                     q1 = numeric(), median = numeric(), 
                     mean = numeric(), q3 = numeric(),
                     max = numeric(), sd = numeric(), 
-                    pcnt_na = numeric(), hist = list()))
+                    pcnt_na = numeric(), hist = list())
     }
   } else {
     # get histogram and summaries for first df
-    s1 <- inspect_num(df1, show_plot = F, breaks = breaks) %>% 
-      select(col_name, mean, sd, hist)
+    s1 <- inspect_num(df1, breaks = breaks) %>% 
+      select(col_name, hist)
     # extract breaks from the above
     breaks_table <- tibble(col_name = s1$col_name, 
                            breaks = lapply(s1$hist, get_break))
-    # get new histoggrams and summary stats using breaks from s1
-    s2 <- inspect_num(df2, breakseq = breaks_table, show_plot = F) %>% 
-      select(col_name, mean, sd, hist)
-    s12 <- full_join(s1, s2, by = "col_name")
-    # calculate psi and fisher p-value
-    levels_tab <- s12 %>%
-      mutate(psi = psi(hist.x, hist.y)) %>%
+    # get new histograms and summary stats using breaks from s1
+    s2 <- inspect_num(df2, breakseq = breaks_table) %>% 
+      select(col_name, hist)
+    out <- full_join(s1, s2, by = "col_name")
+    # calculate js-divergence and fisher p-value
+    out <- out %>%
+      mutate(jsd = js_divergence_vec(hist.x, hist.y)) %>%
       mutate(fisher_p = fisher(hist.x, hist.y, n_1 = nrow(df1), n_2 = nrow(df2))) %>%
-      select(-contains("mean"), -contains("sd"))
-    colnames(levels_tab)[2:3] <- paste0("hist_", 1:2)
-    # if plot is requested
-    if(show_plot){
-      plot_num_2(levels_tab, 
-                 df_names = df_names, 
-                 plot_layout = plot_layout)
-    }
-    # return dataframe
-    return(levels_tab)
+      select(col_name, hist_1 = hist.x, hist_2 = hist.y,  jsd, fisher_p)
+    # attach attributes required for plotting
+    attr(out, "type") <- list("num", 2)
+    attr(out, "df_names") <- df_names
   }
+  if(show_plot) plot_deprecated(out)
+  return(out)
 }
 
 
