@@ -4,12 +4,10 @@
 #' @importFrom ggplot2 scale_fill_manual
 #' @importFrom grDevices colorRampPalette
 #' @importFrom ggplot2 scale_x_discrete
+#' @importFrom ggplot2 scale_colour_manual
 plot_cat <- function(levels_df, df_names, text_labels, high_cardinality, 
-                     cols = cols){
-  # plotting pallete
-  b <- colorRampPalette(c(cols[1], "white"))
-  zcols <- b(1001)
-
+                     cols = c("tomato3", "gray65", "darkmagenta"), 
+                     col_palette){
   # min_freq label
   min_freq_label <- paste0("High cardinality")
 
@@ -19,7 +17,8 @@ plot_cat <- function(levels_df, df_names, text_labels, high_cardinality,
       filter(cnt <= high_cardinality) %>%
       summarise(prop = sum(prop), cnt = sum(cnt)) %>%
       bind_cols(value = min_freq_label, .) %>%
-      bind_rows(z %>% filter(cnt > high_cardinality), .) %>% select(-cnt)
+      bind_rows(z %>% filter(cnt > high_cardinality), .) %>% 
+      select(-cnt)
   }
   
   # the only thing that is used to plot is the levels field
@@ -33,7 +32,8 @@ plot_cat <- function(levels_df, df_names, text_labels, high_cardinality,
                (max(colval) - min(colval) + 0.001)) %>%
       ungroup %>%
       arrange(col_name) %>%
-      mutate(level_key = paste0(value, "-", col_name)) %>% return()
+      mutate(level_key = paste0(value, "-", col_name)) %>% 
+      return()
   }
   
   # select the list column conataining frequency tables
@@ -49,6 +49,8 @@ plot_cat <- function(levels_df, df_names, text_labels, high_cardinality,
                             high_cardinality = high_cardinality)
     lvl_df <- collapse_levels(lvl_df, 1)
     lvl_df$dfi <- df_names[[1]]
+    lvl_df <- lvl_df %>%
+      mutate(col_name2 = col_name)
   } else {
     # first remove column
     if(anyNA(levels_df$jsd)){
@@ -66,6 +68,7 @@ plot_cat <- function(levels_df, df_names, text_labels, high_cardinality,
     lvl_df <- bind_rows(a1, a2)
     # combine df into col_name
     lvl_df <- lvl_df %>% 
+      mutate(col_name2 = col_name) %>%
       mutate(col_name = paste0(col_name, ": ", dfi))
   }
 
@@ -94,25 +97,61 @@ plot_cat <- function(levels_df, df_names, text_labels, high_cardinality,
     mutate(level_key = factor(level_key, 
                               levels = unique(level_key))) %>%
     mutate(col_name = factor(col_name, 
-                             levels = rev(sort(unique(col_name)))))
+                             levels = rev(sort(unique(col_name))))) %>%
+    mutate(col_name2 = factor(col_name2, 
+                             levels = rev(sort(unique(col_name2)))))
 
+  # vector of colours for plotting
+  ncolumns <- length(unique(lvl_df2$col_name2))
+  get_shade_ramp <- function(col){
+    b <- colorRampPalette(c(col, "white"))
+    b(1001)
+  }
+  vcols <- sapply(user_colours(ncolumns, col_palette), get_shade_ramp)
+  col_inds <- cbind(round(lvl_df2$colvalstretch * 1000, 0), as.integer(lvl_df2$col_name2))
+  colour_vector <- vcols[col_inds]
+  colour_vector[is.na(lvl_df2$value)] <- cols[2]
+  colour_vector[lvl_df2$value == min_freq_label] <- cols[3]
   # generate plot
   plt <- lvl_df2 %>%
-    ggplot(aes(x = col_name, y = prop, fill = new_level_key)) +
+    ggplot(aes(x = col_name, y = prop, fill = new_level_key, 
+               label = value)) +
     geom_bar(position = "stack", stat = "identity", 
              colour = "black", size = 0.2) +
-    scale_fill_manual(
-      values = ifelse(is.na(lvl_df2$value), cols[2], 
-                      ifelse(lvl_df2$value == min_freq_label, cols[3], 
-                             zcols[round(lvl_df2$colvalstretch * 1000, 0)]))) +
-    coord_flip() +
+    scale_fill_manual(values = colour_vector) +
     guides(fill = FALSE) + 
+    coord_flip() +
     theme(axis.title.y = element_blank(), panel.background = element_blank(),
           axis.ticks.y = element_blank(), panel.border = element_blank(), 
           panel.grid.major = element_blank(), axis.title.x = element_blank(), 
           axis.text.x = element_blank(), axis.ticks.x = element_blank()) +
     labs(x = "", y = "", 
          subtitle = bquote("Gray segments are missing values")) 
+
+  if(text_labels){
+    annts <- lvl_df2 %>% mutate(col_num = as.integer(col_name))
+    lvl_df2$col_vec <- factor(as.integer(annts$colvalstretch < 0.7), 
+                                 levels = c(1, 0))
+    
+    plt <- plt + 
+      suppressWarnings( 
+        ggfittext::geom_fit_text(
+          data = lvl_df2,
+          aes(x = col_name,
+              y = prop,
+              label = value, 
+              fill = new_level_key, 
+              colour = as.factor(col_vec)),
+          inherit.aes = FALSE,
+          na.rm = TRUE,
+          position = "stack",
+          place = "middle",
+          grow = FALSE, 
+          outside = FALSE, 
+          show.legend = FALSE
+        )) + 
+          scale_colour_manual(values = c("white", "gray55"))
+  }
   
   # if this is a comparison, then add x-axis labels and descriptive title
   if(is_onedf){
@@ -129,19 +168,6 @@ plot_cat <- function(levels_df, df_names, text_labels, high_cardinality,
   # add title
   plt <- plt + labs(title = ttl)
   
-  if(text_labels){
-    # label bars with category name if bar is long enough
-    annts <- lvl_df2 %>% 
-      mutate(col_num = as.integer(col_name))
-    annts$value[annts$prop < 0.15] <- NA
-    col_vec <- ifelse((annts$colvalstretch > 0.7), 2, 1)
-    # if bars are dark, label white, otherwise gray
-    plt <- plt + geom_text(aes(x = annts$col_num, 
-                               y = annts$colval - (annts$prop/2), 
-                               label = annts$value), 
-                           color = c("white", "gray55")[col_vec], 
-                           inherit.aes = FALSE, na.rm = T, hjust = 0.5)
-  }
-  print(plt)
+  suppressWarnings(print(plt))
 }
 
